pub enum Action {
Shift(ItemSetId),
Reduce(RuleId),
}Expand description
An action to be taken upon encountering a symbol.
Variants
Shift(ItemSetId)
Shift the symbol and go to the given item set.
Reduce(RuleId)
Reduce with the given rule.
Implementations